# W3connect

The first skill for AI agent like OpenClaw and Nanobot to access web3.

It is working with google/microsoft authenticator app.

    pip install w3connect

Build in public, wish you enjoy this.

